#include <stdio.h>

int setattr(int type);
int setcolor(int type, int fg_color, int bg_color);
int cursor_up(int step);
int cursor_down(int step);
int cursor_left(int step);
int cursor_right(int step);
int cursor_pos(int y, int x);
int save_cursor(void);
int restore_cursor(void);
int clrscr(void);
int erase_line(void);
void ansi_on(void);
void ansi_off(void);

/* Global vars */
short ansi=1;


/* Modes */
#define ANSI_OFF 0
#define ANSI_BOLD 1
#define ANSI_UNDERSCORE 4
#define ANSI_BLINK 5
#define ANSI_REVERSE 7
#define ANSI_CONCEAL 8

/* Colors */
#define ANSI_BLACK 30
#define ANSI_RED 31
#define ANSI_GREEN 32
#define ANSI_YELLOW 33
#define ANSI_BLUE 34
#define ANSI_MAGENTA 35
#define ANSI_CYAN 36
#define ANSI_WHITE 37

#define ANSI_ERR -1
#define ANSI_OK 0
#define ansi_reset() printf("\033[%i;%i;%im", 0, 37, 40)

int setattr(int type)
{
  if (ansi)
    {
      printf("\033[%i", type);
      return ANSI_OK;
    }
  else
    return ANSI_ERR;
}

int setcolor(int type, int fg_color, int bg_color)
{
  if (ansi)
    {
      bg_color += 10;
      printf("\33[%i;%i;%im", type, fg_color, bg_color);
      return ANSI_OK;
    }
  else
    return ANSI_ERR;
}

/* havent decided yet if to use the "if (ansi)" for these too */

int cursor_up(int step)
{
  printf("\033[%iA", step);
  return 0;
}

int cursor_down(int step)
{
  printf("\033[%iB", step);
  return 0;
}

int cursor_left(int step)
{
  printf("\033[%iD", step);
  return 0;
}

int cursor_right(int step)
{
  printf("\033[%iC", step);
  return 0;
}

int cursor_pos(int y, int x)
{
  printf("\033[%i;%iH", y, x);
  return 0;
}

int save_cursor(void)
{
  printf("\033[s");
  return 0;
}

int restore_cursor(void)
{
  printf("\033[u");
  return 0;
}

int clrscr(void)
{
  printf("\033[2J");
  return 0;
}

int erase_line(void)
{
  printf("\033[K");
  return 0;
}

inline void ansi_on(void)
{
  ansi=1;
}

void ansi_off(void)
{
  ansi_reset();
  ansi=0;
}
